from setuptools import setup, find_packages

setup(
    name="fractalgen",
    version="0.1.0",
    description="A package to generate fractal patterns in Python",
    author="Your Name",
    packages=find_packages(),
    install_requires=["numpy", "matplotlib"],
    python_requires=">=3.7",
)
